<?php
// Version: 1.1; index

/*	This template is, perhaps, the most important template in the theme. It
	contains the main template layer that displays the header and footer of
	the forum, namely with main_above and main_below. It also contains the
	menu sub template, which appropriately displays the menu; the init sub
	template, which is there to set the theme up; (init can be missing.) and
	the linktree sub template, which sorts out the link tree.

	The init sub template should load any data and set any hardcoded options.

	The main_above sub template is what is shown above the main content, and
	should contain anything that should be shown up there.

	The main_below sub template, conversely, is shown after the main content.
	It should probably contain the copyright statement and some other things.

	The linktree sub template should display the link tree, using the data
	in the $context['linktree'] variable.

	The menu sub template should display all the relevant buttons the user
	wants and or needs.

	For more information on the templating system, please see the site at:
	http://www.simplemachines.org/
*/

// Initialize the template... mainly little settings.
function template_init()
{
	global $context, $settings, $options, $txt;

	/* Use images from default theme when using templates from the default theme?
		if this is 'always', images from the default theme will be used.
		if this is 'defaults', images from the default theme will only be used with default templates.
		if this is 'never' or isn't set at all, images from the default theme will not be used. */
	$settings['use_default_images'] = 'never';

	/* What document type definition is being used? (for font size and other issues.)
		'xhtml' for an XHTML 1.0 document type definition.
		'html' for an HTML 4.01 document type definition. */
	$settings['doctype'] = 'xhtml';

	/* The version this template/theme is for.
		This should probably be the version of SMF it was created for. */
	$settings['theme_version'] = '1.1';

	/* Set a setting that tells the theme that it can render the tabs. */
	$settings['use_tabs'] = true;

	/* Use plain buttons - as oppossed to text buttons? */
	$settings['use_buttons'] = true;

	/* Show sticky and lock status seperate from topic icons? */
	$settings['seperate_sticky_lock'] = true;
}

// The main sub template above the content.
function template_main_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	// Show right to left and the character set for ease of translating.
	echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"', $context['right_to_left'] ? ' dir="rtl"' : '', '><head>
	<meta http-equiv="Content-Type" content="text/html; charset=', $context['character_set'], '" />
	<meta name="description" content="', $context['page_title'], '" />', empty($context['robot_no_index']) ? '' : '
	<meta name="robots" content="noindex" />', '
	<meta name="keywords" content="prophecy,witness,two,ruow,news,church,Elijah,ladynada,Jesus,Christ,zion,God,nwo,conspiracy,antichrist,revelation,2012,overcomer,rapture" />
	<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/script.js?fin11"></script>
	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		var smf_theme_url = "', $settings['theme_url'], '";
		var smf_images_url = "', $settings['images_url'], '";
		var smf_scripturl = "', $scripturl, '";
		var smf_iso_case_folding = ', $context['server']['iso_case_folding'] ? 'true' : 'false', ';
		var smf_charset = "', $context['character_set'], '";
	// ]]></script>
	<title>', $context['page_title'], '</title>';

	// The ?fin11 part of this link is just here to make sure browsers don't cache it wrongly.
	echo '
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/style.css?fin11" />
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/print.css?fin11" media="print" />';

	/* Internet Explorer 4/5 and Opera 6 just don't do font sizes properly. (they are big...)
		Thus, in Internet Explorer 4, 5, and Opera 6 this will show fonts one size smaller than usual.
		Note that this is affected by whether IE 6 is in standards compliance mode.. if not, it will also be big.
		Standards compliance mode happens when you use xhtml... */
	if ($context['browser']['needs_size_fix'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/fonts-compat.css" />';

	// Show all the relative links, such as help, search, contents, and the like.
	echo '
	<link rel="help" href="', $scripturl, '?action=help" target="_blank" />
	<link rel="search" href="' . $scripturl . '?action=search" />
	<link rel="contents" href="', $scripturl, '" />';

	// If RSS feeds are enabled, advertise the presence of one.
	if (!empty($modSettings['xmlnews_enable']))
		echo '
	<link rel="alternate" type="application/rss+xml" title="', $context['forum_name'], ' - RSS" href="', $scripturl, '?type=rss;action=.xml" />';

	// If we're viewing a topic, these should be the previous and next topics, respectively.
	if (!empty($context['current_topic']))
		echo '
	<link rel="prev" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=prev" />
	<link rel="next" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=next" />';

	// If we're in a board, or a topic for that matter, the index will be the board's index.
	if (!empty($context['current_board']))
		echo '
	<link rel="index" href="' . $scripturl . '?board=' . $context['current_board'] . '.0" />';

	// We'll have to use the cookie to remember the header...
	if ($context['user']['is_guest'])
		$options['collapse_header'] = !empty($_COOKIE['upshrink']);

	// Output any remaining HTML headers. (from mods, maybe?)
	echo $context['html_headers'], '

	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		var current_header = ', empty($options['collapse_header']) ? 'false' : 'true', ';

		function shrinkHeader(mode)
		{';

	// Guests don't have theme options!!
	if ($context['user']['is_guest'])
		echo '
			document.cookie = "upshrink=" + (mode ? 1 : 0);';
	else
		echo '
			smf_setThemeOption("collapse_header", mode ? 1 : 0, null, "', $context['session_id'], '");';

	echo '
			document.getElementById("upshrink").src = smf_images_url + (mode ? "/upshrink2.gif" : "/upshrink.gif");

			document.getElementById("upshrinkHeader").style.display = mode ? "none" : "";
			document.getElementById("upshrinkHeader2").style.display = mode ? "none" : "";

			current_header = mode;
		}
	// ]]></script>';

	// the routine for the info center upshrink
	echo '
		<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
			var current_header_ic = ', empty($options['collapse_header_ic']) ? 'false' : 'true', ';

			function shrinkHeaderIC(mode)
			{';

	if ($context['user']['is_guest'])
		echo '
				document.cookie = "upshrinkIC=" + (mode ? 1 : 0);';
	else
		echo '
				smf_setThemeOption("collapse_header_ic", mode ? 1 : 0, null, "', $context['session_id'], '");';

	echo '
				document.getElementById("upshrink_ic").src = smf_images_url + (mode ? "/expand.gif" : "/collapse.gif");

				document.getElementById("upshrinkHeaderIC").style.display = mode ? "none" : "";

				current_header_ic = mode;
			}
		// ]]></script>
</head>
<body>';

//  The whole front page starts right here, this is the very top




// now at the very top use as much space as you want for a logo

echo '

<table class="logo_border" cellpadding="0" cellspacing="0" border="0" width="100%" id="upshrinkHeader"', empty($options['collapse_header']) ? '' : ' style="display: none;"', '>
	<tr>
	<td class="logo">';
	if (empty($settings['header_logo_url']))
			{
			echo '
			<div class="nologo">
			' ,' <b>', $context['forum_name'], '</b>
			</div>';
			}
		else
			{
			echo '
			<img class="yeslogo" src="', $settings['header_logo_url'], '" alt="', $context['forum_name'], '" />';
			}	
		echo '
	</td></tr></table>';

// after the logo  a login bar for guests or the avatar bar for the user



if ($context['user']['is_logged'])
	{
	echo '
	
		
	<table class="top_border" width="100%" cellpadding="0" cellspacing="0" border="0" id="upshrinkHeader2"', empty($options['collapse_header']) ? '' : ' style="display: none;"', '>
	<tr>';
		if (!empty($context['user']['avatar']))
				{
				echo '
				<td class="user_avatar" align="center">', $context['user']['avatar']['image'], '</td>';
				}
				echo '
				<td class="user_logged">
				 ', $txt['hello_member_ndt'], ' <b>', $context['user']['name'] , '</b><br /><br />';
		// Is the forum in maintenance mode?
		if ($context['in_maintenance'] && $context['user']['is_admin'])
				{
				echo '
				<b>', $txt[616], '</b><br />';
				}
		// Are there any members waiting for approval?
		if (!empty($context['unapproved_members']))
				{
				echo '
				', $context['unapproved_members'] == 1 ? $txt['approve_thereis'] : $txt['approve_thereare'], ' <a href="', $scripturl, '?action=viewmembers;sa=browse;type=approve">', $context['unapproved_members'] == 1 ? $txt['approve_member'] : $context['unapproved_members'] . ' ' . $txt['approve_members'], '</a> ', $txt['approve_members_waiting'], '<br />';
				}						
					
	
	// Remember the user is logged here
	echo '
	<a class="unread" href="', $scripturl, '?action=unread">', $txt['unread_since_visit'], '</a><br />
	<a class="replies" href="', $scripturl, '?action=unreadreplies">', $txt['show_unread_replies'], '</a><br />';
	// Only tell them about their messages if they can read their messages!
		if ($context['allow_pm'])
				{
				echo '<div class="newmail">';
				echo $txt[152], ' <a href="', $scripturl, '?action=pm">', $context['user']['messages'], ' ', $context['user']['messages'] != 1 ? $txt[153] : $txt[471], '</a>', $txt['newmessages4'], ' ', $context['user']['unread_messages'], ' ', $context['user']['unread_messages'] == 1 ? $txt['newmessages0'] : $txt['newmessages1'];
				echo '.<br /></div>';
				}
	echo '
	</td>	';
		
			
	}
	// Otherwise they're a guest - send them a lovely greeting...
	else
		{
		echo '
		
		<table id="upshrinkHeader2"', empty($options['collapse_header']) ? '' : ' style="display: none;"', ' class="top_border" width="100%" cellpadding="0" cellspacing="0" border="0">
		<tr>
		<td class="guest_login">';
	
		echo $txt['welcome_guest'];	
		echo '	
		<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/sha1.js"></script>
		<form action="', $scripturl, '?action=login2" method="post" accept-charset="', $context['character_set'], '" class="normaltext" style="margin: 3px 1ex 1px 0;"', empty($context['disable_login_hashing']) ? ' onsubmit="hashLoginPassword(this, \'' . $context['session_id'] . '\');"' : '', '>
		<input type="text" name="user" size="10" /> <input type="password" name="passwrd" size="10" />
		<select name="cookielength">
		<option value="60">', $txt['smf53'], '</option>
		<option value="1440">', $txt['smf47'], '</option>
		<option value="10080">', $txt['smf48'], '</option>
		<option value="43200">', $txt['smf49'], '</option>
		<option value="-1" selected="selected">', $txt['smf50'], '</option>
		</select>
		<input type="submit" value="', $txt[34], '" /><br />
		<span class="guest_login2">', $txt['smf52'], '</span>
		<input type="hidden" name="hash_passwrd" value="" />
		</form>	
		</td>';
		}


// now in the center at the top, some forum stats
	echo '
		
	<td class="forum_stats">';
	echo '	 	
	 	', $txt[645], '<br />
	 	', $txt[19], ': ', $context['common_stats']['total_members'], ' <br />', $txt[95], ': ', $context['common_stats']['total_posts'], ' <br />',  $txt[64], ': ', $context['common_stats']['total_topics'], '
	 	', ($settings['show_latest_member'] ? '<br /> New User:' .  ' <b>' . $context['common_stats']['latest_member']['link'] . '</b>' : '');
	echo '
	</td>';
	echo '
	
	<td class="top_search">';
	
	
// now on the right at the top a search box	
echo '
		<form action="', $scripturl, '?action=search2" method="post" accept-charset="', $context['character_set'], '" style="margin: 0;">
		<a href="', $scripturl, '?action=search;advanced"><img src="'.$settings['images_url'].'/filter.gif" align="middle" style="margin: 0 1ex;" alt="" /></a>
		<input type="text" name="search" value="" style="width: 177px;" />&nbsp;
		<input type="submit" name="submit" value="', $txt[182], '" style="width: 11ex;" />
		
		<input type="hidden" name="advanced" value="0" />';

	// Search within current topic?
	if (!empty($context['current_topic']))
	{
		echo '
		<input type="hidden" name="topic" value="', $context['current_topic'], '" />';
	}		

		// If we're on a certain board, limit it to this board ;).
	elseif (!empty($context['current_board']))
	{
		echo '
		<input type="hidden" name="brd[', $context['current_board'], ']" value="', $context['current_board'], '" />';
	}		

	echo '
		<br /><br /> 
		<div style="text-decoration: none; margin-bottom: 3px; margin-left: 8px; padding: 2px 8px 6px 8px; background-color: #F1F1F1; border: outset 2px #95929C; float: left; cursor: pointer;" onmouseover="this.style.backgroundColor=\'#DDEEFD\'" onmouseout="this.style.backgroundColor=\'#F1F1F1\'">
		<a href="', $scripturl, '?action=search;advanced" onclick="this.href += \';search=\' + escape(document.searchform.search.value);">', $txt['smf298'], '</a>
		</div>
		<input type="hidden" name="advanced" value="0" />
		</form>
		</td>	
				
		</tr>
	 	</table>';


echo '

	<table class="topline" align="center"  width="100%" cellpadding="0" cellspacing="0" border="0">
	
		<tr>';
				


// A single bar with user name and time of day
// First a name (user) or (guest) at the far left at the top
// This is a member				

if ($context['user']['is_logged'])
	{
	echo '
	<td class="topline_user" style="text-align: left;">
	', 'Welcome Back ', ' <b>', $context['user']['name'] , '</b>
	</td>';									
	}
// Otherwise they're a guest - mention them on the  bar
	else
	{			
	echo '<td class="topline_user" style="text-align: left;">';
	echo $txt['welcome_guest'];
	echo '
	</td>';
	}
// Now the forum name in the center at the top
	echo '
	<td class="topline_forumname" style="text-align: center; font-size: large;">
	' ,' <b>', $context['forum_name'], '</b>
	</td>';			

// Now the time at the far right at the top
	echo '
	<td class="topline_time" style="text-align: right;">
	' ,' <b>', $context['current_time'], '</b>
	<a href="#" onclick="shrinkHeader(!current_header); return false;"><img id="upshrink" src="', $settings['images_url'], '/', empty($options['collapse_header']) ? 'upshrink.gif' : 'upshrink2.gif', '" alt="*" title="', $txt['upshrink_description'], '" align="right" style="margin: 0 1ex;" /></a>

	</td>';
		
	echo '
	
	</tr>
	
	</table>	
	
	
	<table width="100%" cellpadding="0" cellspacing="0" border="0">
	<tr>
	<td class="button_back">';




//  The TOP part of the front page STOPPED above this line!


	// Show the menu here, according to the menu sub template.
	template_menu();

echo '
</td></tr></table>';
	// The main content should go here.  A table is used because IE 6 just can't handle a div.
		echo '
		
		<table width="100%" cellpadding="0" cellspacing="0" border="0">
		<tr>
		<td id="bodyarea">';
}

function template_main_below()
{
	global $context, $settings, $options, $scripturl, $txt;

	

	// Show the "Powered by" and "Valid" logos, as well as the copyright. Remember, the copyright must be somewhere!
	echo '

	<div id="footerarea" style="text-align: center; padding-bottom: 1ex;', $context['browser']['needs_size_fix'] && !$context['browser']['is_ie6'] ? ' width: 100%;' : '', '">
		<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
			function smfFooterHighlight(element, value)
			{
				element.src = smf_images_url + "/" + (value ? "h_" : "") + element.id + ".gif";
			}
		// ]]></script>
		
		


		
<table cellspacing="0" cellpadding="3" border="0" align="center" width="100%">
<!-- // Quick Theme Changer Start -->
	<tr>
		<td colspan="3" style="text-align: center;">
		<select class="skin_changer" name="quick_theme_changer" onchange="quick_theme_changer(this)">
		<optgroup label="', $txt['quick_theme_changer'], '">';
			foreach ($context['themes'] as $theme)
				{
				echo '<option value="', $theme['id'], '"', (($settings['theme_id'] == $theme['id']) ? 'selected="selected"' : ''), '>', $theme['name'], '</option>';
				}
		echo '</optgroup>
		</select>
		</td>
	</tr>
<!-- // Quick Theme Changer Script -->
	<script language="JavaScript" type="text/javascript">
		function quick_theme_changer(obj)
		{
		var id = obj.options[obj.selectedIndex].value;
		var url = new String(window.location);
		loc = \'index.php?theme=\' + id + \';saa=quick\' + \';url=\' + escape(url);
		window.location = loc;
		}
	</script>
<!-- // Quick Theme Changer End -->
		
			<tr>
				<td width="28%" valign="middle" align="', !$context['right_to_left'] ? 'right' : 'left', '">
					<a href="http://www.mysql.com/" target="_blank"><img id="powered-mysql" src="', $settings['images_url'], '/powered-mysql.gif" alt="', $txt['powered_by_mysql'], '" width="54" height="20" style="margin: 5px 16px;" onmouseover="smfFooterHighlight(this, true);" onmouseout="smfFooterHighlight(this, false);" /></a>
					<a href="http://www.php.net/" target="_blank"><img id="powered-php" src="', $settings['images_url'], '/powered-php.gif" alt="', $txt['powered_by_php'], '" width="54" height="20" style="margin: 5px 16px;" onmouseover="smfFooterHighlight(this, true);" onmouseout="smfFooterHighlight(this, false);" /></a>
				</td>
				<td valign="middle" align="center" style="white-space: nowrap;">
					', theme_copyright(), '
				</td>
				<td width="28%" valign="middle" align="', !$context['right_to_left'] ? 'left' : 'right', '">
					<a href="http://validator.w3.org/check/referer" target="_blank"><img id="valid-xhtml10" src="', $settings['images_url'], '/valid-xhtml10.gif" alt="', $txt['valid_xhtml'], '" width="54" height="20" style="margin: 5px 16px;" onmouseover="smfFooterHighlight(this, true);" onmouseout="smfFooterHighlight(this, false);" /></a>
					<a href="http://jigsaw.w3.org/css-validator/check/referer" target="_blank"><img id="valid-css" src="', $settings['images_url'], '/valid-css.gif" alt="', $txt['valid_css'], '" width="54" height="20" style="margin: 5px 16px;" onmouseover="smfFooterHighlight(this, true);" onmouseout="smfFooterHighlight(this, false);" /></a>
				</td>
				
				
				
			</tr>
		</table>';
		/*
		
		<table  width="100%" cellpadding="0" cellspacing="0" border="0" align="center">
						<tr>
									
						
						
									<td>';
										echo"<!--~~~CrawlTrack~~~~~~~~~~~~~~~~~~~~-->\n";
										$crawltsite=1;
										include("/home/ladynada/public_html/crawltrack/crawltrack.php");
										echo"<p><a href=\"http://www.crawltrack.fr\">
										<img src=\"http://heartdaughter.com/crawltrack/images/logo10.png\" alt=\"CrawlTrack: free crawlers and spiders tracking script- SEO script -script gratuit de d�tection des robots\" width=\"80\" height=\"15\" style=\"border:0\"/>
										</a></p>\n";
										echo"<!--~~~CrawlTrack~~~~~~~~~~~~~~~~~~~~-->\n";
										echo '
			</td>	</tr></table>
			*/
			
				
		// Show the load time?
	if ($context['show_load_time'])
		echo '
		<span class="normaltext">', $txt['smf301'], $context['load_time'], $txt['smf302'], $context['load_queries'], $txt['smf302b'], '</span>';

	// This is an interesting bug in Internet Explorer AND Safari. Rather annoying, it makes overflows just not tall enough.
	if (($context['browser']['is_ie'] && !$context['browser']['is_ie4']) || $context['browser']['is_mac_ie'] || $context['browser']['is_safari'] || $context['browser']['is_firefox'])
	{
		// The purpose of this code is to fix the height of overflow: auto div blocks, because IE can't figure it out for itself.
		echo '
		<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[';

		// Unfortunately, Safari does not have a "getComputedStyle" implementation yet, so we have to just do it to code...
		if ($context['browser']['is_safari'])
			echo '
			window.addEventListener("load", smf_codeFix, false);

			function smf_codeFix()
			{
				var codeFix = document.getElementsByTagName ? document.getElementsByTagName("div") : document.all.tags("div");

				for (var i = 0; i < codeFix.length; i++)
				{
					if ((codeFix[i].className == "code" || codeFix[i].className == "post" || codeFix[i].className == "signature") && codeFix[i].offsetHeight < 20)
						codeFix[i].style.height = (codeFix[i].offsetHeight + 20) + "px";
				}
			}';
		elseif ($context['browser']['is_firefox'])
			echo '
			window.addEventListener("load", smf_codeFix, false);
			function smf_codeFix()
			{
				var codeFix = document.getElementsByTagName ? document.getElementsByTagName("div") : document.all.tags("div");

				for (var i = 0; i < codeFix.length; i++)
				{
					if (codeFix[i].className == "code" && (codeFix[i].scrollWidth > codeFix[i].clientWidth || codeFix[i].clientWidth == 0))
						codeFix[i].style.overflow = "scroll";
				}
			}';			
		elseif ($context['browser']['is_firefox'])
					echo '
					window.addEventListener("load", smf_codeFix, false);
					function smf_codeFix()
					{
						var codeFix = document.getElementsByTagName ? document.getElementsByTagName("div") : document.all.tags("div");
		
						for (var i = 0; i < codeFix.length; i++)
						{
							if (codeFix[i].className == "code" && (codeFix[i].scrollWidth > codeFix[i].clientWidth || codeFix[i].clientWidth == 0))
								codeFix[i].style.overflow = "scroll";
						}
					}';
				else
					echo '
			var window_oldOnload = window.onload;
			window.onload = smf_codeFix;

			function smf_codeFix()
			{
				var codeFix = document.getElementsByTagName ? document.getElementsByTagName("div") : document.all.tags("div");

				for (var i = codeFix.length - 1; i > 0; i--)
				{
					if (codeFix[i].currentStyle.overflow == "auto" && (codeFix[i].currentStyle.height == "" || codeFix[i].currentStyle.height == "auto") && (codeFix[i].scrollWidth > codeFix[i].clientWidth || codeFix[i].clientWidth == 0) && (codeFix[i].offsetHeight != 0 || codeFix[i].className == "code"))
						codeFix[i].style.height = (codeFix[i].offsetHeight + 36) + "px";
				}

				if (window_oldOnload)
				{
					window_oldOnload();
					window_oldOnload = null;
				}
			}';

		echo '
		// ]]></script>';
	}

	echo '
	</div>';
	// The Div above this line closed the footerarea
	
	echo '

	
	
	</td></tr></table>';
	

	


	// The following will be used to let the user know that some AJAX process is running
	echo '
	<div id="ajax_in_progress" style="display: none;', $context['browser']['is_ie'] && !$context['browser']['is_ie7'] ? 'position: absolute;' : '', '">', $txt['ajax_in_progress'], '</div>
</body></html>';
}



// Show a linktree. This is that thing that shows "My Community | General Category | General Discussion"..


function theme_linktree()
{


	global $context, $settings, $options, $txt, $scripturl, $showtree, $modSettings;
	



// Let's do something completely different with the linktree!
	
// lets set up our own array to get the data first, and then use it to draw a nice table

// sets our array and makes sure it is blank (no elements)

$showtree = (array) $showtree;


// echo 'total count in showtree is ', count($showtree);

$mycount = 0;
$addmod = 0;
$showmod = "";
foreach ($context['linktree'] as $link_num => $tree)
{
	$mycount=$mycount + 1;
	
	$tempholder = "";
		if  ($settings['linktree_link'] && isset($tree['url']))
			{
			$tempholder = '<a href="' . $tree['url'] . '" style="text-decoration: none;">' . $tree['name'] . '</a>';
			}
		else
			{
			$tempholder = $tree['name'];
			}
			
	$showtree[$mycount] = $tempholder;
	
	
	// echo '<br />mycount is ', $mycount;
	// echo ' and showtree  is ', $showtree[$mycount];
	
	
	
}	

// If $showmod is non-zero then it holds the moderator
if ($mycount >= 4)
	{
		
		if (isset($context['linktree'][count($context['linktree']) - 2]['extra_after']))
		{
		$showmod = $context['linktree'][count($context['linktree']) - 2]['extra_after'];
		$showtree[$mycount+1] = $context['linktree'][count($context['linktree']) - 2]['extra_after'];
	 	// echo '<br />mycount is ', $mycount;
		// echo ' and showtree  is ', $showtree[$mycount+1];
		$addmod = 1;
	 	}
			
	}
		
	// echo '<br />total count in showtree is ', count($showtree), '<br />';
	// echo '<br />showmod  is ', $showmod , '<br />';
	// echo '<br />addmod  is ', $addmod , '<br />';
	// print_r($showtree);

// echo '<br />switch statement results <br />';	
	
// now we have the linktree elements in the $showtree array and the count in mycount
// also we know if the count in $showtree is one more than mycount, that we have a moderator



switch ($mycount) {
case 0:
    echo "huge error";
    break;
case 1:
    // echo ' BBS NAME ONLY ';
    echo '
    	<div class="nav_border">
    		<table cellspacing="0" cellpadding="0" border="0" align="center" width="100%">
    			<tr>
    		    		<td class="top_linktree" valign="top"><b>';
    		    		echo $showtree[1];
    		    		echo '
    		    		</b></td>
	    		</tr>
		</table></div>';	    		
    break;
case 2:
    // echo ' BBS NAME AND Category or Other ';
echo '
	<div class="nav_border">
    		<table cellspacing="0" cellpadding="0" border="0" align="center" width="100%">
    			<tr>
    		    		<td class="top_linktree" valign="top"><b>';
    		    		echo $showtree[1];
    		    		echo '
    		    		</b></td>
	    		</tr>
	    		<tr>
	    			<td rowspan="2" class="single_cat" style="text-align: center;">';
				echo $showtree[2];
				echo '
				</td>
			</tr>									
		</table></div>';	     		
    break;
case 3:
    // echo ' BBS NAME AND Category And Board name ';
echo '
	<div class="nav_border">
    		<table cellspacing="0" cellpadding="0" border="0" align="center" width="100%">
    			<tr>
    		    	<th class="top_linktree" valign="top">';
			echo $showtree[1];
			echo '				
			</th>
			<th colspan="2" class="board_cat" style="text-align: center;">';
			echo $showtree[2];
			echo '
			</th></tr><tr>';
			echo '
			<td class="board_name" style="text-align: center;">';
			echo $showtree[3];
			echo '
			</td><td>';
			boardblurb();
			echo '
			</td>
			</tr>									
		</table></div>';	      
    break;    
case 4:
	if ($addmod == 0)
	{
	// echo ' BBS NAME AND Category And Board name and childboard name  if case 4';
	
echo '
	<div class="nav_border">
    		<table cellspacing="0" cellpadding="0" border="0" align="center" width="100%">
    			<tr>
    		    		<th class="top_linktree" valign="top">';
				echo $showtree[1];
			echo '				
			</th>
			<th colspan="2" class="board_cat" style="text-align: center;">';
			echo $showtree[2];
			echo '
			</th></tr><tr>';
			echo '
			<td class="board_name" style="text-align: center;">';
			echo $showtree[3];
			echo '
			</td>
			<td class="board_child" style="text-align: center;">';
			echo $showtree[4];
			echo '
			</td>
			</tr>									
		</table></div>';	     	
    	
    		
	
	
	
	}
	else
	{
    	// echo ' BBS NAME AND Category And Board name and message subject (with moderator) else case 4 ';

echo '
	<div class="nav_border">
    		<table cellspacing="0" cellpadding="0" border="0" align="center" width="100%">
    			<tr>
    		    	<th class="top_linktree" valign="top">';
			echo $showtree[1];
			echo '				
			</th>
			<th colspan="2" class="board_cat" style="text-align: center;">';
			echo $showtree[2];
			echo '
			</th></tr><tr>';
			echo '
			<td class="board_name" style="text-align: center;">';
			echo $showtree[3];
			echo '
			</td>
			<td class="board_msg">';
			echo $showtree[4];
			echo '
			</td>
			<td class="board_mod">';
			echo $showmod;
			echo '
			</td>
			</tr>									
		</table></div>';	     	
    	
    	
    	}
    break;  
case 5:
    if ($addmod == 0)
	{
	// echo ' BBS NAME AND Category And Board name and childboard name and CHILD of CHILD board name if case 5';
	
	
echo '
	<div class="nav_border">
    		<table cellspacing="0" cellpadding="0" border="0" align="center" width="100%">
    			<tr>
    		    	<th class="top_linktree" valign="top">';
			echo $showtree[1];
			echo '				
			</th>
			<th colspan="2" class="board_cat" style="text-align: center;">';
			echo $showtree[2];
			echo '
			</th></tr><tr>';
			echo '
			<td  rowspan="2" class="board_name" style="text-align: center;">';
			echo $showtree[3];
			echo '
			</td>
			<td class="board_child" style="text-align: center;">';
			echo $showtree[4];
			echo '
			</td><td class="board_child" style="text-align: center;">';
			echo $showtree[5];
			echo '
			</td>
			</tr>									
		</table></div>';	
	
	
	}
	else
	{
    	// echo ' BBS NAME AND Category And Board name and childboard name and message subject (with moderator) else case 5';
echo '
	<div class="nav_border">
    		<table cellspacing="0" cellpadding="0" border="0" align="center" width="100%">
    			<tr>
    		    	<th class="top_linktree" valign="top">';
			echo $showtree[1];
			echo '				
			</th>
			<td class="board_name" style="text-align: center;">';
			echo $showtree[3];
			echo '
			</td>
			<td class="side_desc">';
			echo $txt['smf82'];
			echo '
			</td>
			</tr>
			<tr>
			<th rowspan="2" class="board_cat" style="text-align: center;">';
			echo $showtree[2];
			echo '
			</th>
			<td class="board_child" style="text-align: center;">';
			echo $showtree[4];
			echo '
			</td>
			<td class="side_desc">';
			echo $txt[23];
			echo '
			</td>
			</tr><tr>			
			<td class="board_msg">';
			echo $showtree[5];
			echo '
			</td>
			<td class="board_mod">';
			echo $showmod;
			echo '
			</td>
			</tr>									
		</table></div>';	     	
   
    	
    	}  
    break; 
case 6:
if ($addmod == 0)
	{
	// echo ' BBS NAME AND Category And Board name and childboard name and CHILD of CHILD board name and CHILD of CHILD of CHILD board name if case 6';
	
	
 echo '
	<div class="nav_border">
    		<table cellspacing="0" cellpadding="0" border="0" align="center" width="100%">
    			<tr>
    		    	<th class="top_linktree" valign="top">';
			echo $showtree[1];
			echo '				
			</th>
			<td class="board_child" style="text-align: center;">';
			echo $showtree[4];
			echo '
			</td>
			
			</tr>
			<tr>
			<th class="board_cat" style="text-align: center;">';
			echo $showtree[2];
			echo '
			</th>
			<td class="board_child" style="text-align: center;">';
			echo $showtree[5];
			echo '
			</td>
			
			</tr><tr>
			<th class="board_name" style="text-align: center;">';
			echo $showtree[3];
			echo '
			</th>
			
			<td class="board_child" style="text-align: center;">';
			echo $showtree[6];
			echo '
			</td>
			
			</tr>									
		</table></div>';	     	
 
	
	}
	else
	{
    	// echo ' BBS NAME AND Category And Board name and childboard name and childboard name  and message subject (with moderator)  else case 6 ';
    	
    	
    	
 echo '
	<div class="nav_border">
    		<table cellspacing="0" cellpadding="0" border="0" align="center" width="100%">
    			<tr>
    		    	<th class="top_linktree" valign="top">';
			echo $showtree[1];
			echo '				
			</th>
			<td class="board_child" style="text-align: center;">';
			echo $showtree[4];
			echo '
			</td>
			<td class="side_desc">';
			echo $txt[23];
			echo '
			</td>
			</tr>
			<tr>
			<th class="board_cat" style="text-align: center;">';
			echo $showtree[2];
			echo '
			</th>
			<td class="board_child" style="text-align: center;">';
			echo $showtree[5];
			echo '
			</td>
			<td class="side_desc">';
			echo $txt[23];
			echo '
			</td>
			
			</tr><tr>
			<th class="board_name" style="text-align: center;">';
			echo $showtree[3];
			echo '
			</th>
			
			<td class="board_msg">';
			echo $showtree[6];
			echo '
			</td>
			
			
			<td class="board_mod">';
			echo $showmod;
			echo '
			</td>
			</tr>									
		</table></div>';	     	
   
    	
 	 }
      break;      
default:
   // echo "you have too many child boards YO !";
}

if ($mycount > 6)
{
echo '
	 <div class="nav_border">';


		
// My custom linktree starts here			
		echo '
			<table width="100%" cellpadding="0" cellspacing="0">
			<tr>';	
	
	// Each tree item has a URL and name. Some may have extra_before and extra_after.
$mycount = 0;
foreach ($context['linktree'] as $link_num => $tree)
{
	
		$mycount=$mycount + 1;
	//	echo 'this is $mycount  ', $mycount;
		if ($mycount == 1)
		{
			
			echo '
			<td class="top_linktree" valign="top">';
			echo '<b>', $settings['linktree_link'] && isset($tree['url']) ? '<a href="' . $tree['url'] . '" style="font-decoration: none;">' . $tree['name'] . '</a>' : $tree['name'], '</b>
			</td></tr>';                                                                      
		}
			elseif ($mycount ==2)		
			{
			// Show the link, including a URL if it should have one.
			echo '
			<tr><td rowspan="2" class="board_cat" style="text-align: center;">';
			
		
			echo '<b>', $settings['linktree_link'] && isset($tree['url']) ? '<a href="' . $tree['url'] . '" style="text-decoration: none;">' . $tree['name'] . '</a>' : $tree['name'], '</b>';
			
			echo '
			</td>';
			}
				elseif ($mycount == 3)		
				{
				// Show the link, including a URL if it should have one.
				echo '
				<th colspan="3" class="board_blurb" align="center">';
				boardblurb();
				echo '
								
				
				</th>
				</tr><tr>
				<td class="board_name" style="text-align: center;">';
				echo '<b>', $settings['linktree_link'] && isset($tree['url']) ? '<a href="' . $tree['url'] . '" style="text-decoration: none;">' . $tree['name'] . '</a>' : $tree['name'], '</b>';
				echo '
				</td>';
				}	
					elseif ($mycount >= 4)
					{
					$temp = $context['linktree'][count($context['linktree']) - 2]['extra_after'];
						if ($temp != '')
						{
						// Show the link, including a URL if it should have one.
						echo '
						<td class="board_msg">';
						echo '<b>', $settings['linktree_link'] && isset($tree['url']) ? '<a href="' . $tree['url'] . '" style="text-decoration: none;">' . $tree['name'] . '</a>' : $tree['name'], '</b>';
						echo '
						</td>';
						}
							else
							{
							echo '
							<td class="board_child" style="text-align: center;">';
							echo '<b>', $settings['linktree_link'] && isset($tree['url']) ? '<a href="' . $tree['url'] . '" style="text-decoration: none;">' . $tree['name'] . '</a>' : $tree['name'], '</b>';
							echo '
							</td>';
							}
					}				
		
		
		
				}
	// Don't show a separator for the last one.
			if ($mycount >= 4)
			{
			$temp = $context['linktree'][count($context['linktree']) - 2]['extra_after'];
			if ($temp != '')
			{
			echo '<td class="board_mod">', $context['linktree'][count($context['linktree']) - 2]['extra_after'], '</td>';
			
			}
		}

if ($mycount == 1)
		{
			echo '
			</table></div>';
		}	
if ($mycount == 2)
		{
			echo '
			</tr></table></div>';
		}	
if ($mycount >= 4)
		{
			echo '
			</tr></table></div>';
		}		

	
}

}

// Show the menu up top. Something like [home] [help] [profile] [logout]...
function template_menu()
{
	global $context, $settings, $options, $scripturl, $txt;

	// Work out where we currently are.
	$current_action = 'home';
	if (in_array($context['current_action'], array('admin', 'ban', 'boardrecount', 'cleanperms', 'detailedversion', 'dumpdb', 'featuresettings', 'featuresettings2', 'findmember', 'maintain', 'manageattachments', 'manageboards', 'managecalendar', 'managesearch', 'membergroups', 'modlog', 'news', 'optimizetables', 'packageget', 'packages', 'permissions', 'pgdownload', 'postsettings', 'regcenter', 'repairboards', 'reports', 'serversettings', 'serversettings2', 'smileys', 'viewErrorLog', 'viewmembers')))
		$current_action = 'admin';
	if (in_array($context['current_action'], array('search', 'admin', 'calendar', 'profile', 'mlist', 'register', 'login', 'help', 'pm')))
		$current_action = $context['current_action'];
	if ($context['current_action'] == 'search2')
		$current_action = 'search';
	if ($context['current_action'] == 'theme')
		$current_action = isset($_REQUEST['sa']) && $_REQUEST['sa'] == 'pick' ? 'profile' : 'admin';

	// Are we using right-to-left orientation?
	if ($context['right_to_left'])
	{
		$first = 'last';
		$last = 'first';
	}
	else
	{
		$first = 'first';
		$last = 'last';
	}

	// Show the start of the tab section.
	echo '
			<table cellpadding="0" cellspacing="0" border="0" style="margin-left: 10px;">
				<tr>
					<td class="maintab_' , $first , '">&nbsp;</td>';

	// Show the [home] button.
	echo ($current_action=='home' || $context['browser']['is_ie4']) ? '<td class="maintab_active_' . $first . '">&nbsp;</td>' : '' , '
				<td valign="top" class="maintab_' , $current_action == 'home' ? 'active_back' : 'back' , '">
					<a href="', $scripturl, '">' , $txt[103] , '</a>
				</td>' , $current_action == 'home' ? '<td class="maintab_active_' . $last . '">&nbsp;</td>' : '';

	// Show the [help] button.
	echo ($current_action == 'help' || $context['browser']['is_ie4']) ? '<td class="maintab_active_' . $first . '">&nbsp;</td>' : '' , '
				<td valign="top" class="maintab_' , $current_action == 'help' ? 'active_back' : 'back' , '">
					<a href="', $scripturl, '?action=help">' , $txt[119] , '</a>
				</td>' , $current_action == 'help' ? '<td class="maintab_active_' . $last . '">&nbsp;</td>' : '';

	// How about the [search] button?
	if ($context['allow_search'])
		echo ($current_action == 'search' || $context['browser']['is_ie4']) ? '<td class="maintab_active_' . $first . '">&nbsp;</td>' : '' , '
				<td valign="top" class="maintab_' , $current_action == 'search' ? 'active_back' : 'back' , '">
					<a href="', $scripturl, '?action=search">' , $txt[182] , '</a>
				</td>' , $current_action == 'search' ? '<td class="maintab_active_' . $last . '">&nbsp;</td>' : '';

	// Is the user allowed to administrate at all? ([admin])
	if ($context['allow_admin'])
		echo ($current_action == 'admin' || $context['browser']['is_ie4']) ? '<td class="maintab_active_' . $first . '">&nbsp;</td>' : '' , '
				<td valign="top" class="maintab_' , $current_action == 'admin' ? 'active_back' : 'back' , '">
					<a href="', $scripturl, '?action=admin">' , $txt[2] , '</a>
				</td>' , $current_action == 'admin' ? '<td class="maintab_active_' . $last . '">&nbsp;</td>' : '';

	// Edit Profile... [profile]
	if ($context['allow_edit_profile'])
		echo ($current_action == 'profile' || $context['browser']['is_ie4']) ? '<td class="maintab_active_' . $first . '">&nbsp;</td>' : '' , '
				<td valign="top" class="maintab_' , $current_action == 'profile' ? 'active_back' : 'back' , '">
					<a href="', $scripturl, '?action=profile">' , $txt[79] , '</a>
				</td>' , $current_action == 'profile' ? '<td class="maintab_active_' . $last . '">&nbsp;</td>' : '';

	// Go to PM center... [pm]
	if ($context['user']['is_logged'] && $context['allow_pm'])
		echo ($current_action == 'pm' || $context['browser']['is_ie4']) ? '<td class="maintab_active_' . $first . '">&nbsp;</td>' : '' , '
				<td valign="top" class="maintab_' , $current_action == 'pm' ? 'active_back' : 'back' , '">
					<a href="', $scripturl, '?action=pm">' , $txt['pm_short'] , ' ', $context['user']['unread_messages'] > 0 ? '[<strong>'. $context['user']['unread_messages'] . '</strong>]' : '' , '</a>
				</td>' , $current_action == 'pm' ? '<td class="maintab_active_' . $last . '">&nbsp;</td>' : '';

	// The [calendar]!
	if ($context['allow_calendar'])
		echo ($current_action == 'calendar' || $context['browser']['is_ie4']) ? '<td class="maintab_active_' . $first . '">&nbsp;</td>' : '' , '
				<td valign="top" class="maintab_' , $current_action == 'calendar' ? 'active_back' : 'back' , '">
					<a href="', $scripturl, '?action=calendar">' , $txt['calendar24'] , '</a>
				</td>' , $current_action == 'calendar' ? '<td class="maintab_active_' . $last . '">&nbsp;</td>' : '';

	// the [member] list button
	if ($context['allow_memberlist'])
		echo ($current_action == 'mlist' || $context['browser']['is_ie4']) ? '<td class="maintab_active_' . $first . '">&nbsp;</td>' : '' , '
				<td valign="top" class="maintab_' , $current_action == 'mlist' ? 'active_back' : 'back' , '">
					<a href="', $scripturl, '?action=mlist">' , $txt[331] , '</a>
				</td>' , $current_action == 'mlist' ? '<td class="maintab_active_' . $last . '">&nbsp;</td>' : '';


	// If the user is a guest, show [login] button.
	if ($context['user']['is_guest'])
		echo ($current_action == 'login' || $context['browser']['is_ie4']) ? '<td class="maintab_active_' . $first . '">&nbsp;</td>' : '' , '
				<td valign="top" class="maintab_' , $current_action == 'login' ? 'active_back' : 'back' , '">
					<a href="', $scripturl, '?action=login">' , $txt[34] , '</a>
				</td>' , $current_action == 'login' ? '<td class="maintab_active_' . $last . '">&nbsp;</td>' : '';


	// If the user is a guest, also show [register] button.
	if ($context['user']['is_guest'])
		echo ($current_action == 'register' || $context['browser']['is_ie4']) ? '<td class="maintab_active_' . $first . '">&nbsp;</td>' : '' , '
				<td valign="top" class="maintab_' , $current_action == 'register' ? 'active_back' : 'back' , '">
					<a href="', $scripturl, '?action=register">' , $txt[97] , '</a>
				</td>' , $current_action == 'register' ? '<td class="maintab_active_' . $last . '">&nbsp;</td>' : '';


	// Otherwise, they might want to [logout]...
	if ($context['user']['is_logged'])
		echo ($current_action == 'logout' || $context['browser']['is_ie4']) ? '<td class="maintab_active_' . $first . '">&nbsp;</td>' : '' , '
				<td valign="top" class="maintab_' , $current_action == 'logout' ? 'active_back' : 'back' , '">
					<a href="', $scripturl, '?action=logout;sesc=', $context['session_id'], '">' , $txt[108] , '</a>
				</td>' , $current_action == 'logout' ? '<td class="maintab_active_' . $last . '">&nbsp;</td>' : '';

	// The end of tab section.
	echo '
				<td class="maintab_' , $last , '">&nbsp;</td>
			</tr>
		</table>';

}


// Generate a strip of buttons.
function template_button_strip($button_strip, $direction = 'top', $force_reset = false, $custom_td = '')
{
	global $settings, $buttons, $context, $txt, $scripturl;

	// Create the buttons...
	foreach ($button_strip as $key => $value)
	{
		if (isset($value['test']) && empty($context[$value['test']]))
		{
			unset($button_strip[$key]);
			continue;
		}
		elseif (!isset($buttons[$key]) || $force_reset)
			$buttons[$key] = '<a href="' . $value['url'] . '" ' .( isset($value['custom']) ? $value['custom'] : '') . '>' . $txt[$value['text']] . '</a>';

		$button_strip[$key] = $buttons[$key];
	}

	if (empty($button_strip))
		return '<td>&nbsp;</td>';

	echo '
		<td class="', $direction == 'top' ? 'main' : 'mirror', 'tab_' , $context['right_to_left'] ? 'last' : 'first' , '">&nbsp;</td>
		<td class="', $direction == 'top' ? 'main' : 'mirror', 'tab_back">', implode(' &nbsp;|&nbsp; ', $button_strip) , '</td>
		<td class="', $direction == 'top' ? 'main' : 'mirror', 'tab_' , $context['right_to_left'] ? 'first' : 'last' , '">&nbsp;</td>';
}


// Show a blurb about user's mail or to guests, a login menu and option to register, all with linktree
function boardblurb()
{
global $context, $settings, $options, $scripturl, $txt, $ultiportal, $boardurl, $login_url, $old_url, $logout_url;
echo '
<table  width="100%" cellpadding="0" cellspacing="0" border="0" align="center">
	<tr>';
		if ($context['user']['is_logged'])
			{
				echo '
					<td class="user_boardblurb" style="text-align: center;">
					 <a class="unread" href="', $scripturl, '?action=unread">', $txt['unread_since_visit'], '</a><br />
					 <a class="replies" href="', $scripturl, '?action=unreadreplies">', $txt['show_unread_replies'], '</a><br />';
					 // Only tell them about their messages if they can read their messages!
					 	if ($context['allow_pm'])
					 		{
					 			echo $txt[152], ' <a href="', $scripturl, '?action=pm">', $context['user']['messages'], ' ', $context['user']['messages'] != 1 ? $txt[153] : $txt[471], '</a>', $txt['newmessages4'], ' ', $context['user']['unread_messages'], ' ', $context['user']['unread_messages'] == 1 ? $txt['newmessages0'] : $txt['newmessages1'];
					 			echo '.<br />';
					 		}
					 echo '
					 </td>';
				
			}
		// Otherwise they're a guest - mention them on the site bar
		else
			{			
				echo '<td class="guest_boardblurb">';
					echo $txt['welcome_guest'];
				echo '
					</td>';

			}


echo '
</tr></table>';

}




?>